@@ -619,7 +619,16 @@ g_digicam_camerabin_element_new (const gchar *videosrc,
 
     if (NULL != ienc) {
         if (0 != quality) {
-            g_object_set (G_OBJECT (ienc), "quality", quality, NULL);
+            if (NULL != g_object_class_find_property (G_OBJECT_GET_CLASS (ienc),
+                                                      "quality")) {
+                g_object_set (G_OBJECT (ienc), "quality", quality, NULL);
+            } else {
+                G_DIGICAM_DEBUG ("GDigicamCamerabin::g_digicam_camerabin_element_new: "
+                                 "image encoder has not quality capabilities.");
+            }
+        } else {
+            G_DIGICAM_DEBUG ("GDigicamCamerabin::g_digicam_camerabin_element_new: "
+                             "quality not specified for image encoder.");
         }
 
 	g_object_set (G_OBJECT (gst_camera_bin), "imageenc", ienc, NULL);
@@ -2135,6 +2144,8 @@ _g_digicam_camerabin_set_video_metadata (GstElement *gst_camera_bin,
 
     GstTagSetter *setter = NULL;
     GstTagList *list = NULL;
+    gchar *geo_name = NULL;
+    gchar *tmp = NULL;
     /*we should not set Date if hantro is used as its automatically set by it.
     If we set date and time, hantro extract only year from it and erase the automatic date */
     /*TODO: Verfiy aumatice date set. */
@@ -2195,19 +2206,29 @@ _g_digicam_camerabin_set_video_metadata (GstElement *gst_camera_bin,
 
     /* We should have all the geotags. */
     if (NULL != metadata->country_name) {
-        gst_tag_list_add (list, GST_TAG_MERGE_APPEND,
-                          GST_TAG_GEO_LOCATION_COUNTRY, metadata->country_name,
-                          NULL);
+        geo_name = g_strdup (metadata->country_name);
         if (NULL != metadata->city_name) {
-                gst_tag_list_add (list, GST_TAG_MERGE_APPEND,
-                                  GST_TAG_GEO_LOCATION_CITY, metadata->city_name,
-                                  NULL);
-            }
-        if (NULL != metadata->suburb_name) {
-            gst_tag_list_add (list, GST_TAG_MERGE_APPEND,
-                              GST_TAG_GEO_LOCATION_SUBLOCATION, metadata->suburb_name,
-                              NULL);
+            tmp = g_strconcat (geo_name,
+                               ",",
+                               metadata->city_name,
+                               NULL);
+            g_free (geo_name);
+            geo_name = tmp;
+            tmp = NULL;
         }
+        if (NULL != metadata->suburb_name) {
+            tmp = g_strconcat (geo_name,
+                               ",",
+                               metadata->suburb_name,
+                               NULL);
+            g_free (geo_name);
+            geo_name = tmp;
+            tmp = NULL;
+        }
+
+        gst_tag_list_add (list, GST_TAG_MERGE_APPEND,
+                          GST_TAG_GEO_LOCATION_NAME, geo_name,
+                          NULL);
     }
 
     /* Set metadata tags. */
@@ -2216,6 +2237,8 @@ _g_digicam_camerabin_set_video_metadata (GstElement *gst_camera_bin,
 
     /* Free. */
     gst_tag_list_free (list);
+    g_free (geo_name);
+    g_free (tmp);
 }
 
 
